@@ -38,6 +38,17 @@ BOOL LcMemMap_GetRangesAsStruct(_In_ PLC_CONTEXT ctxLC, _Out_ PBYTE * ppbDataOut
 _Success_(return)
 BOOL LcMemMap_GetRangesAsText(_In_ PLC_CONTEXT ctxLC, _Out_ PBYTE *ppbDataOut, _Out_opt_ PDWORD pcbDataOut);
 
+/*
+* Set ranges by memmap struct data.
+* NB! all previous ranges will be overwritten.
+* -- ctxLC
+* -- pStruct
+* -- cStruct
+* -- return
+*/
+_Success_(return)
+BOOL LcMemMap_SetRangesFromStruct(_In_ PLC_CONTEXT ctxLC, _In_ PLC_MEMMAP_ENTRY pMemMap, _In_ DWORD cMemMap);
+
 /*
 * Set ranges by parsing ascii text in the buffer pb. The ranges should be
 * specified on a line-by-line basis with hexascii numericals on the format:
